@@ -15,22 +15,20 @@
 
 from .operator import Operator
 from .map import Map
-from .map_reduce import MapReduce
-from .reduction import Reduction
+from .tree_reduce import TreeReduce
+from .reduce import Reduce
 from .fold import Fold
 from .binary import Binary
-from .groupby import (
-    GroupByReduce,
-    groupby_reduce_functions,
-)
+from .groupby import GroupByReduce, groupby_reduce_functions, is_reduce_function
 
 __all__ = [
     "Operator",
     "Map",
-    "MapReduce",
-    "Reduction",
+    "TreeReduce",
+    "Reduce",
     "Fold",
     "Binary",
     "GroupByReduce",
     "groupby_reduce_functions",
+    "is_reduce_function",
 ]
