@@ -14,11 +14,13 @@
 """Module houses class that implements ``GenericRayDataframePartitionManager`` using Ray."""
 
 import inspect
-import numpy as np
 import threading
 
+import numpy as np
+import ray
+
 from modin.config import ProgressBar, NPartitions
-from modin.core.execution.ray.generic.partitioning.partition_manager import (
+from modin.core.execution.ray.generic.partitioning import (
     GenericRayDataframePartitionManager,
 )
 from .virtual_partition import (
@@ -28,10 +30,7 @@ from .virtual_partition import (
 from .partition import PandasOnRayDataframePartition
 from modin.core.execution.ray.generic.modin_aqp import call_progress_bar
 from modin.core.storage_formats.pandas.utils import compute_chunksize
-from modin.error_message import ErrorMessage
-import pandas
-
-import ray
+from pandas._libs.lib import no_default
 
 
 def progress_bar_wrapper(f):
@@ -96,47 +95,21 @@ class PandasOnRayDataframePartitionManager(GenericRayDataframePartitionManager):
     _row_partition_class = PandasOnRayDataframeRowPartition
 
     @classmethod
-    def get_indices(cls, axis, partitions, index_func=None):
+    def get_objects_from_partitions(cls, partitions):
         """
-        Get the internal indices stored in the partitions.
+        Get the objects wrapped by `partitions` in parallel.
 
         Parameters
         ----------
-        axis : {0, 1}
-            Axis to extract the labels over.
         partitions : np.ndarray
             NumPy array with ``PandasDataframePartition``-s.
-        index_func : callable, default: None
-            The function to be used to extract the indices.
 
         Returns
         -------
-        pandas.Index
-            A ``pandas.Index`` object.
-
-        Notes
-        -----
-        These are the global indices of the object. This is mostly useful
-        when you have deleted rows/columns internally, but do not know
-        which ones were deleted.
+        list
+            The objects wrapped by `partitions`.
         """
-        ErrorMessage.catch_bugs_and_request_email(not callable(index_func))
-        func = cls.preprocess_func(index_func)
-        if axis == 0:
-            # We grab the first column of blocks and extract the indices
-            new_idx = (
-                [idx.apply(func).oid for idx in partitions.T[0]]
-                if len(partitions.T)
-                else []
-            )
-        else:
-            new_idx = (
-                [idx.apply(func).oid for idx in partitions[0]]
-                if len(partitions)
-                else []
-            )
-        new_idx = ray.get(new_idx)
-        return new_idx[0].append(new_idx[1:]) if len(new_idx) else new_idx
+        return ray.get([partition.oid for partition in partitions])
 
     @classmethod
     def concat(cls, axis, left_parts, right_parts):
@@ -178,10 +151,9 @@ class PandasOnRayDataframePartitionManager(GenericRayDataframePartitionManager):
 
         Rebalance the partitions by building a new array
         of partitions out of the original ones so that:
-          - If all partitions have a length, each new partition has roughly the
-            same number of rows.
-          - Otherwise, each new partition spans roughly the same number of old
-            partitions.
+
+        - If all partitions have a length, each new partition has roughly the same number of rows.
+        - Otherwise, each new partition spans roughly the same number of old partitions.
 
         Parameters
         ----------
@@ -286,54 +258,6 @@ class PandasOnRayDataframePartitionManager(GenericRayDataframePartitionManager):
             start = stop + 1
         return np.array(new_partitions)
 
-    @classmethod
-    def broadcast_apply(cls, axis, apply_func, left, right, other_name="r"):
-        """
-        Broadcast the `right` partitions to `left` and apply `apply_func` to selected indices.
-
-        Parameters
-        ----------
-        axis : {0, 1}
-            Axis to apply and broadcast over.
-        apply_func : callable
-            Function to apply.
-        left : np.ndarray
-            NumPy 2D array of left partitions.
-        right : np.ndarray
-            NumPy 2D array of right partitions.
-        other_name : str, default: "r"
-            Name of key-value argument for `apply_func` that
-            is used to pass `right` to `apply_func`.
-
-        Returns
-        -------
-        np.ndarray
-            An array of partition objects.
-        """
-
-        def map_func(df, *others):
-            other = pandas.concat(others, axis=axis ^ 1)
-            return apply_func(df, **{other_name: other})
-
-        map_func = cls.preprocess_func(map_func)
-        rt_axis_parts = cls.axis_partition(right, axis ^ 1)
-        return np.array(
-            [
-                [
-                    part.apply(
-                        map_func,
-                        *(
-                            rt_axis_parts[col_idx].list_of_blocks
-                            if axis
-                            else rt_axis_parts[row_idx].list_of_blocks
-                        ),
-                    )
-                    for col_idx, part in enumerate(left[row_idx])
-                ]
-                for row_idx in range(len(left))
-            ]
-        )
-
     @classmethod
     @progress_bar_wrapper
     def map_partitions(cls, partitions, map_func):
@@ -550,7 +474,7 @@ class PandasOnRayDataframePartitionManager(GenericRayDataframePartitionManager):
         func,
         row_partitions_list,
         col_partitions_list,
-        item_to_distribute=None,
+        item_to_distribute=no_default,
         row_lengths=None,
         col_widths=None,
     ):
@@ -567,7 +491,7 @@ class PandasOnRayDataframePartitionManager(GenericRayDataframePartitionManager):
             List of row partitions.
         col_partitions_list : list
             List of column partitions.
-        item_to_distribute : item, optional
+        item_to_distribute : np.ndarray or scalar, default: no_default
             The item to split up so it can be applied over both axes.
         row_lengths : list of ints, optional
             Lengths of partitions for every row. If not specified this information
