@@ -102,6 +102,23 @@ class BaseIO(object):
         """
         return cls.query_compiler_cls.from_arrow(at, cls.frame_cls)
 
+    @classmethod
+    def from_dataframe(cls, df):
+        """
+        Create a Modin QueryCompiler from a DataFrame supporting the DataFrame exchange protocol `__dataframe__()`.
+
+        Parameters
+        ----------
+        df : DataFrame
+            The DataFrame object supporting the DataFrame exchange protocol.
+
+        Returns
+        -------
+        BaseQueryCompiler
+            QueryCompiler containing data from the DataFrame.
+        """
+        return cls.query_compiler_cls.from_dataframe(df, cls.frame_cls)
+
     @classmethod
     @_inherit_docstrings(pandas.read_parquet, apilink="pandas.read_parquet")
     @doc(
@@ -830,7 +847,10 @@ class BaseIO(object):
         compression: CompressionOptions = "infer",
         protocol: int = pickle.HIGHEST_PROTOCOL,
         storage_options: StorageOptions = None,
-    ):  # noqa: PR01
+    ):  # noqa: PR01, D200
+        """
+        Pickle (serialize) object to file.
+        """
         ErrorMessage.default_to_pandas("`to_pickle`")
         if isinstance(obj, BaseQueryCompiler):
             obj = obj.to_pandas()
