@@ -37,7 +37,6 @@ import pyarrow as pa
 
 import pandas
 import pandas._libs.lib as lib
-from pandas._typing import FilePathOrBuffer
 from pandas.io.common import is_url
 
 ReadCsvKwargsType = Dict[
@@ -51,7 +50,6 @@ ReadCsvKwargsType = Dict[
         Sequence,
         Callable,
         Dialect,
-        FilePathOrBuffer,
         None,
     ],
 ]
@@ -62,11 +60,7 @@ class ArrowEngineException(Exception):
 
 
 class OmnisciOnNativeIO(BaseIO, TextFileDispatcher):
-    """
-    Class contains IO functions implementations with OmniSci storage format and Native engine.
-
-    Inherits some common for OmniSci engine util functions from ``BaseIO`` class.
-    """
+    """Class contains IO functions implementations with OmniSci storage format and Native engine."""
 
     frame_cls = OmnisciOnNativeDataframe
     query_compiler_cls = DFAlgQueryCompiler
@@ -437,7 +431,7 @@ class OmnisciOnNativeIO(BaseIO, TextFileDispatcher):
             return (
                 False,
                 "read_csv with 'arrow' engine doesn't support explicit compression parameter, compression"
-                " must be inferred automatically (supported compression types are gzip and bz2)",
+                + " must be inferred automatically (supported compression types are gzip and bz2)",
             )
 
         if isinstance(filepath_or_buffer, str):
@@ -472,20 +466,24 @@ class OmnisciOnNativeIO(BaseIO, TextFileDispatcher):
             )
 
         parse_dates_unsupported = isinstance(parse_dates, dict) or (
-            isinstance(parse_dates, list) and isinstance(parse_dates[0], list)
+            isinstance(parse_dates, list)
+            and any(not isinstance(date, str) for date in parse_dates)
         )
         if parse_dates_unsupported:
             return (
                 False,
-                "read_csv with 'arrow' engine supports only bool and "
-                "flattened lists 'parse_dates' parameter",
+                (
+                    "read_csv with 'arrow' engine supports only bool and "
+                    + "flattened list of string column names for the "
+                    + "'parse_dates' parameter"
+                ),
             )
         if names and names != lib.no_default:
             if header not in [None, 0, "infer"]:
                 return (
                     False,
                     "read_csv with 'arrow' engine and provided 'names' parameter supports only 0, None and "
-                    "'infer' header values",
+                    + "'infer' header values",
                 )
             if isinstance(parse_dates, list) and not set(parse_dates).issubset(names):
                 raise ValueError("Missing column provided to 'parse_dates'")
@@ -508,14 +506,14 @@ class OmnisciOnNativeIO(BaseIO, TextFileDispatcher):
                 return (
                     False,
                     "read_csv with 'arrow' engine doesn't support names parameter, which length doesn't match "
-                    "with actual number of columns",
+                    + "with actual number of columns",
                 )
         else:
             if header not in [0, "infer"]:
                 return (
                     False,
                     "read_csv with 'arrow' engine without 'names' parameter provided supports only 0 and 'infer' "
-                    "header values",
+                    + "header values",
                 )
             if isinstance(parse_dates, list):
                 empty_pandas_df = pandas.read_csv(
@@ -582,13 +580,13 @@ class OmnisciOnNativeIO(BaseIO, TextFileDispatcher):
         if delim_whitespace and (delimiter is not lib.no_default):
             raise ValueError(
                 "Specified a delimiter with both sep and "
-                "delim_whitespace=True; you can only specify one."
+                + "delim_whitespace=True; you can only specify one."
             )
         if on_bad_lines is not None:
             if error_bad_lines is not None or warn_bad_lines is not None:
                 raise ValueError(
                     "Both on_bad_lines and error_bad_lines/warn_bad_lines are set. "
-                    "Please only set on_bad_lines."
+                    + "Please only set on_bad_lines."
                 )
 
         if on_bad_lines not in ["error", "warn", "skip", None]:
